${c.pkg_dict.get('title', c.pkg_dict['name'])} - Datasets - History History: ${c.pkg.title or c.pkg.name}

### Revisions

### Error: ${c.error}

| Revision | Timestamp | Author | Log Message
--- | --- | --- | --- | ---
${h.radio("selected1", rev.id, checked=(index == 0))} ${h.radio("selected2", rev.id, checked=(index == len(c.pkg_revisions)-1))} | ${rev['id'][:4]}… | ${h.render_datetime(rev['timestamp'])} | ${h.linked_user(rev['author'])} | ${rev['message']}